CVE-2023-3442 | Security Lab
Author: Your Name
Description: Missing Authorization in Jenkins plug-in for ServiceNow DevOps
Date: 2023-07-26T00:00:00-07:00

# CVE-2023-3442

PUBLISHED

# Summary

Missing Authorization in Jenkins plug-in for ServiceNow DevOps

# Description

A missing authorization vulnerability exists in versions of the Jenkins Plug-in for ServiceNow DevOps prior to 1.38.1 that, if exploited successfully, could cause the unwanted exposure of sensitive information. To address this issue, apply the 1.38.1 version of the Jenkins plug-in for ServiceNow DevOps on your Jenkins server. No changes are required on your instances of the Now Platform.

# Severity

7.7 (CVSS:3.1/AV:N/AC:L/PR:L/UI:N/S:C/C:H/I:N/A:N)

# Affected Versions

This vulnerability is present in the following Affected Product(s) listed below.

Affected Product(s)
cpe:2.3:a:jenkins:servicenow_devops:*:*:*:*:*:jenkins:*:*

# References

- https://support.servicenow.com/kb?id=kb_article_view&sysparm_article=KB1434119

# Change History

Date | Note
--- | ---
2023-07-26 | Initial publication
2023-07-26 | Last updated

Enter your search term...